==> pantomime-1.0.4.tgz: Local/Headers/Pantomime/Store.h <==
/*
**  Store.h
**
**  Copyright (c) 2001, 2002
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**  
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
**  Lesser General Public License for more details.
**  
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

#import <Foundation/Foundation.h>

@class Folder;

@protocol Store

- (id) initWithURL: (NSString *) theURL;

- (id) defaultFolder;
- (id) folderForName: (NSString *) theName;
- (id) folderForURL: (NSString *) theURL;

- (NSEnumerator *) folderEnumerator;
- (NSEnumerator *) subscribedFolderEnumerator;
- (NSEnumerator *) openedFoldersEnumerator;
- (void) removeFolderFromOpenedFolders: (Folder *) theFolder;

- (BOOL) folderForNameIsOpen: (NSString *) theName;

- (int) folderTypeForFolderName: (NSString *) theName;

- (NSString *) folderSeparator;

- (void) close;

- (BOOL) createFolderWithName: (NSString *) theName;
- (BOOL) deleteFolderWithName: (NSString *) theName;
- (BOOL) renameFolderWithName: (NSString *) theName
                       toName: (NSString *) theNewName;

@end

==> pantomime-1.1.0.tgz: Local/Headers/Pantomime/Store.h <==
/*
**  Store.h
**
**  Copyright (c) 2001, 2002, 2003
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**  
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
**  Lesser General Public License for more details.
**  
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

#ifndef _Pantomime_H_Store
#define _Pantomime_H_Store

#import <Foundation/NSEnumerator.h>
#import <Foundation/NSString.h>

@class Folder;

@protocol Store

- (id) initWithURL: (NSString *) theURL;

- (id) defaultFolder;
- (id) folderForName: (NSString *) theName;
- (id) folderForURL: (NSString *) theURL;

- (NSEnumerator *) folderEnumerator;
- (NSEnumerator *) subscribedFolderEnumerator;
- (NSEnumerator *) openedFoldersEnumerator;
- (void) removeFolderFromOpenedFolders: (Folder *) theFolder;

- (BOOL) folderForNameIsOpen: (NSString *) theName;

- (int) folderTypeForFolderName: (NSString *) theName;

- (NSString *) folderSeparator;

- (void) close;

- (BOOL) createFolderWithName: (NSString *) theName 
                         type: (int) theType;
- (BOOL) deleteFolderWithName: (NSString *) theName;
- (BOOL) renameFolderWithName: (NSString *) theName
                       toName: (NSString *) theNewName;

@end

#endif // _Pantomime_H_Store
